@@ -2,10 +2,12 @@
 if [ ! -f index.cache.bz2 ] ; then
 	echo making new index.cache.bz2 ...
 	/usr/bin/meinproc --check --cache index.cache.bz2 ./index.docbook
+#	/opt/kde/bin/meinproc --check --cache index.cache.bz2 ./index.docbook
 else
 	if [ index.cache.bz2  -ot index.docbook ] ; then
 		echo making newer index.cache.bz2 ...
 		/usr/bin/meinproc --check --cache index.cache.bz2 ./index.docbook
+#		/opt/kde/bin/meinproc --check --cache index.cache.bz2 ./index.docbook
 	fi
 fi
 
@@ -17,13 +19,15 @@ if [ ! -e dtd ] ; then
 	if [ ! -z $dn ] ; then ln -s $dn ; fi
 fi
 
+dirname=`pwd`
+
 cd ../HTML
-if [ -e ../en/dtd ]; then
-	if [  ! -f klearnnotes2.html  -o  klearnnotes2.html -ot ../en/index.docbook  ] ; then
+if [ -e $dirname/dtd ]; then
+	if [  ! -f klearnnotes2.html  -o  klearnnotes2.html -ot $dirname/index.docbook  ] ; then
 		echo making html files ...
 		rm -f *.html
-		docbook2html ../en/index.docbook
-		mv book1.html klearnnotes2.html
+		docbook2html $dirname/index.docbook
+		cp book1.html klearnnotes2.html
 
 		echo making Makefile.am
 
