@@ -12,7 +12,12 @@
 #include "noteBLU.xpm"
 #include "noteGRE.xpm"
 #include "noteRED.xpm"
+#include "noteBRO.xpm"
 #include "level_0.xpm" 
 #include "level_1.xpm"
 #include "level_2.xpm"
 
+#include "micOff.xpm"
+#include "micOn.xpm"
+
+#include "twolines.xpm"
